# coding: utf-8

"""
    InductivaWebAPI

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501

from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List
from inductiva.client.models.storage_file_info import StorageFileInfo
from typing import Optional, Set
from typing_extensions import Self


class StorageContentsWithPagination(BaseModel):
    """
    StorageContentsWithPagination
    """

  # noqa: E501
    total_files: StrictInt
    available_regions: List[StrictStr]
    contents: Dict[str, StorageFileInfo]
    __properties: ClassVar[List[str]] = [
        "total_files", "available_regions", "contents"
    ]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of StorageContentsWithPagination from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each value in contents (dict)
        _field_dict = {}
        if self.contents:
            for _key_contents in self.contents:
                if self.contents[_key_contents]:
                    _field_dict[_key_contents] = self.contents[
                        _key_contents].to_dict()
            _dict['contents'] = _field_dict
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of StorageContentsWithPagination from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "total_files":
                obj.get("total_files"),
            "available_regions":
                obj.get("available_regions"),
            "contents":
                dict((_k, StorageFileInfo.from_dict(_v))
                     for _k, _v in obj["contents"].items())
                if obj.get("contents") is not None else None
        })
        return _obj
